==> paraview-5.10.1-9-x86_64.pkg.tar.zst: opt/paraview/include/paraview/vtkUtilitiesPythonInitializerModule.h <==

#ifndef VTKUTILITIESPYTHONINITIALIZER_EXPORT_H
#define VTKUTILITIESPYTHONINITIALIZER_EXPORT_H

#ifdef VTKUTILITIESPYTHONINITIALIZER_STATIC_DEFINE
#  define VTKUTILITIESPYTHONINITIALIZER_EXPORT
#  define VTKUTILITIESPYTHONINITIALIZER_NO_EXPORT
#else
#  ifndef VTKUTILITIESPYTHONINITIALIZER_EXPORT
#    ifdef PythonInitializer_EXPORTS
        /* We are building this library */
#      define VTKUTILITIESPYTHONINITIALIZER_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKUTILITIESPYTHONINITIALIZER_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKUTILITIESPYTHONINITIALIZER_NO_EXPORT
#    define VTKUTILITIESPYTHONINITIALIZER_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKUTILITIESPYTHONINITIALIZER_DEPRECATED
#  define VTKUTILITIESPYTHONINITIALIZER_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKUTILITIESPYTHONINITIALIZER_DEPRECATED_EXPORT
#  define VTKUTILITIESPYTHONINITIALIZER_DEPRECATED_EXPORT VTKUTILITIESPYTHONINITIALIZER_EXPORT VTKUTILITIESPYTHONINITIALIZER_DEPRECATED
#endif

#ifndef VTKUTILITIESPYTHONINITIALIZER_DEPRECATED_NO_EXPORT
#  define VTKUTILITIESPYTHONINITIALIZER_DEPRECATED_NO_EXPORT VTKUTILITIESPYTHONINITIALIZER_NO_EXPORT VTKUTILITIESPYTHONINITIALIZER_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKUTILITIESPYTHONINITIALIZER_NO_DEPRECATED
#    define VTKUTILITIESPYTHONINITIALIZER_NO_DEPRECATED
#  endif
#endif

#endif /* VTKUTILITIESPYTHONINITIALIZER_EXPORT_H */

==> paraview-5.12.1-4-x86_64.pkg.tar.zst: opt/paraview/include/paraview/vtkUtilitiesPythonInitializerModule.h <==

#ifndef VTKUTILITIESPYTHONINITIALIZER_EXPORT_H
#define VTKUTILITIESPYTHONINITIALIZER_EXPORT_H

#ifdef VTKUTILITIESPYTHONINITIALIZER_STATIC_DEFINE
#  define VTKUTILITIESPYTHONINITIALIZER_EXPORT
#  define VTKUTILITIESPYTHONINITIALIZER_NO_EXPORT
#else
#  ifndef VTKUTILITIESPYTHONINITIALIZER_EXPORT
#    ifdef PythonInitializer_EXPORTS
        /* We are building this library */
#      define VTKUTILITIESPYTHONINITIALIZER_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKUTILITIESPYTHONINITIALIZER_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKUTILITIESPYTHONINITIALIZER_NO_EXPORT
#    define VTKUTILITIESPYTHONINITIALIZER_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKUTILITIESPYTHONINITIALIZER_DEPRECATED
#  define VTKUTILITIESPYTHONINITIALIZER_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKUTILITIESPYTHONINITIALIZER_DEPRECATED_EXPORT
#  define VTKUTILITIESPYTHONINITIALIZER_DEPRECATED_EXPORT VTKUTILITIESPYTHONINITIALIZER_EXPORT VTKUTILITIESPYTHONINITIALIZER_DEPRECATED
#endif

#ifndef VTKUTILITIESPYTHONINITIALIZER_DEPRECATED_NO_EXPORT
#  define VTKUTILITIESPYTHONINITIALIZER_DEPRECATED_NO_EXPORT VTKUTILITIESPYTHONINITIALIZER_NO_EXPORT VTKUTILITIESPYTHONINITIALIZER_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKUTILITIESPYTHONINITIALIZER_NO_DEPRECATED
#    define VTKUTILITIESPYTHONINITIALIZER_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkUtilitiesPythonInitializerModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKUTILITIESPYTHONINITIALIZER_EXPORT_H */
